AliAuthPluginWebApi class

阿里云号码认证 Web 插件(Dart 封装)

Constructors

AliAuthPluginWebApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAuthAvailable(String accessToken, String jwtToken, void success(dynamic status), void error(dynamic status)) Future<void>
调用之前先去用户服务端获取 accessToken 和 jwtToken
getConnection() Future<String?>
网络类型检查接口
getVerifyToken(void success(dynamic status), void error(dynamic status)) Future<void>
身份鉴权成功后才可调用获取 Token 接口
getVersion() Future<String?>
获取版本号
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLoggerEnable(bool isEnable) Future<void>
设置 SDK 是否开启日志。开启后会在控制台打印更多内容便于排查问题。
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited