Params class
Constructors
- Params({String? accessToken, String? jwtToken, JSFunction? success, JSFunction? error})
-
factory
Properties
- accessToken ↔ String?
-
getter/setter pair
- error ↔ JSFunction?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- jwtToken ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success ↔ JSFunction?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited