PhoneNumberServer class

Annotations
  • @JS('PhoneNumberServer')

Constructors

PhoneNumberServer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAuthAvailable(Params params) → void
getConnection() Future<String?>
getVerifyToken(Params params) → void
getVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLoggerEnable(bool isEnable) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited